@@ -68,34 +68,3 @@ void ColumnControlDlg::on__pShowButton_clicked()
 	_pShownList->insertItem(_pShownList->count(), pItem);
 }
 
-
-void ColumnControlDlg::on__pUpButton_clicked()
-{
- /*  Q3ListBoxItem* pItem = _pShownList->selectedItem();
-   if (!pItem)
-		return;
-	int index = _pShownList->index(pItem);
-	QString text = pItem->text();
-   // if it is already the first item
-	if (index==0)
-      return;
-   _pShownList->removeItem(index);
-   _pShownList->insertItem(text, index-1);
-	_pShownList->setSelected(index-1, true);*/
-}
-
-void ColumnControlDlg::on__pDownButton_clicked()
-{
-/*	if (_pShownList->selectedItems().size() == 0)
-		return;
-   Q3ListBoxItem* pItem = _pShownList->selectedItem();
-   int index = _pShownList->index(pItem);
-	QString text = pItem->text();
-	// if it is already the last item
-   if (index==_pShownList->count()-1)
-      return;
-   _pShownList->removeItem(index);
-   _pShownList->insertItem(text, index+1);
-	_pShownList->setSelected(index+1, true);*/
-}
-
