@@ -19,6 +19,7 @@
 
 #include <qstring.h>
 
+#include <iostream>
 
 /** Converts the given string to a QString. This should mean no more overhead than
   * doing it manually. */
@@ -62,8 +63,8 @@ inline void qStrWarning(const QString& string)
 	qWarning(string.toAscii());
 }
 
-/** Makes the given string lower case.
-  * @returns a reference to the transformed string (which is the one handed. */
+/** @brief Makes the given string lower case - modifies the handed string.
+  * @returns a reference to the transformed string (which is the one handed). */
 inline std::string& makeLower(std::string& trans)
 {
 	std::transform(trans.begin(), trans.end(), trans.begin(), myToLower);
@@ -79,4 +80,11 @@ inline std::string toLower(const std::string& in)
 	return result;
 }
 
+/** Operator for outputting QStrings. */
+inline std::ostream& operator<< (std::ostream& out, const QString& str) 
+{
+	out << str.toAscii().data();
+	return out;
+}
+
 #endif	// __HELPERS_H_2004_06_23
