@@ -23,7 +23,7 @@
 #include <qclipboard.h>
 #include <QCloseEvent>
 #include <qcursor.h>
-#include <qdir.h>
+#include <QDir>
 #include <qicon.h>
 #include <QList>
 #include <qmessagebox.h>
@@ -48,7 +48,7 @@
 #include "applicationfactory.h"
 #include "runcommand.h"
 #include "runcommandforoutput.h"
-
+#include "gainroot.h"
 
 // namespace NPlugin 
 #include "plugin.h"
@@ -60,7 +60,7 @@
 #include "pluginmanager.h"
 #include "packagenotfoundexception.h"
 #include "plugincompare.h"
-#include "pluginsettingsdlg.h"
+#include "settingsdlg.h"
 #include "packagenameplugin.h"
 #include "scoredisplayplugin.h"
 
@@ -99,17 +99,44 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
 {
 	setObjectName(name);
 	setupUi(this);
- 	delete _pPackageView;
+
+	_pApt = new ept::apt::Apt;
+	_pDebtags = new ept::debtags::Debtags;
+	_pTextsearch = new ept::textsearch::TextSearch;
+
+	// set up what's this actions
+	_pWhatsThisAction = QWhatsThis::createAction(this);
+	_pWhatsThisAction->setShortcut(QKeySequence("Shift+F1"));
+	
+	initDirectories();
+	// don't change order, because initMenus relies on an initialized toolbar
+	initToolbars();
+	initMenus();
+
+	// delete placeholder ListViewWidget and replace by a custom class
+	delete _pPackageView;
 	_pPackageView = new NPackageSearch::PackageDisplayWidget(_pPackageViewFrame);
 	_pPackageView->setWhatsThis("Displays the packages matching the search entered above.");
  	_pPackageViewFrame->layout()->addWidget(_pPackageView);
-	// former ui.h initialization
-	init();
+	
+	
 	_pPackageNamePlugin = 0;
 	_pScoreDisplayPlugin = 0;
 	_settingsFilename = QDir::homePath()+"/.packagesearch";
 	_pInformationDetailsPage = _pInformationContainer->widget(0);
 
+	// setting up window geometry (must happen before loading settings
+	// since otherwise stored geometry would be overridden)
+	uint width = 700;
+	uint height = 600;
+	QList<int> sizes;
+	sizes.push_back(width/2);
+	sizes.push_back((width+1)/2);
+	resize(width, height);
+	_pUpperVSplitter->setSizes(sizes);
+	_pLowerVSplitter->setSizes(sizes);
+
+
 	vector<string> pluginDirectories;
 	pluginDirectories.push_back("plugins/");
 	pluginDirectories.push_back("/usr/lib/packagesearch/");
@@ -118,29 +145,25 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
 	_pPluginManager->addPluginUser(packageView());
 	loadSettings();	// must be called after setting _pPluginManager but before calling loadPlugins
 	
-	_pApt = new ept::apt::Apt;
-	_pDebtags = new ept::debtags::Debtags;
-	_pTextsearch = new ept::textsearch::TextSearch;
+	QPixmap appIcon(_iconDir+"packagesearch.png");
+	setWindowIcon(appIcon);
 
-
-	QIcon backIcon(_iconDir + "back.png");
-	QIcon forwardIcon(_iconDir + "forward.png");
-	_pBackButton->setIcon(backIcon);
-	_pForwardButton->setIcon(forwardIcon);
-    connect(_pPackageView, SIGNAL(packageSelected(QString)), SLOT(onPackageSelectionChanged(QString)));
-    connect(_pClearSearchButton, SIGNAL(clicked()), SLOT(onClearSearch()));
-    connect(helpAboutAction, SIGNAL(triggered()), SLOT(onHelpAboutAction()));
-    connect(helpContentsAction, SIGNAL(triggered()), SLOT(onHelpContentsAction()));
-    connect(_pBackButton, SIGNAL(clicked()), SLOT(onBack()));
-    connect(_pForwardButton, SIGNAL(clicked()), SLOT(onForward()));
-    connect(_pExitAction, SIGNAL(triggered()), SLOT(close()));
-    connect(_pDetailsView, SIGNAL(sourceChanged(const QUrl&)), SLOT(onLinkClicked(const QUrl&)));
-    connect(_pInformationContainer, SIGNAL(currentChanged(int)), SLOT(onInformationPageChanged()));
-    connect(_pControlPluginsAction, SIGNAL(triggered()), SLOT(onControlPlugins()));
-    connect(_pPreferencesAction, SIGNAL(triggered()), SLOT(onPreferences()));
-    connect(_pPackageSelection, SIGNAL(activated(const QString&)), SLOT(selectNewPackage(const QString&)));
-    connect(&timer, SIGNAL(timeout()), SLOT(checkAptDbForUpdates()));
-    timer.start(2000);
+	connect(_pClearSearchButton, SIGNAL(clicked()), SLOT(onClearSearch()));
+	connect(_pBackButton, SIGNAL(clicked()), SLOT(onBack()));
+	connect(_pForwardButton, SIGNAL(clicked()), SLOT(onForward()));
+	connect(_pControlPluginsAction, SIGNAL(triggered()), SLOT(onControlPlugins()));
+	connect(_pPreferencesAction, SIGNAL(triggered()), SLOT(onPreferences()));
+	connect(_pExitAction, SIGNAL(triggered()), SLOT(close()));
+	connect(_pHelpAboutAction, SIGNAL(triggered()), SLOT(onHelpAboutAction()));
+	connect(_pHelpContentsAction, SIGNAL(triggered()), SLOT(onHelpContentsAction()));
+    
+	connect(_pPackageView, SIGNAL(packageSelected(QString)), SLOT(onPackageSelectionChanged(QString)));
+	connect(_pPackageSelection, SIGNAL(activated(const QString&)), SLOT(selectNewPackage(QString)));
+	connect(_pDetailsView, SIGNAL(sourceChanged(const QUrl&)), SLOT(onLinkClicked(const QUrl&)));
+	connect(_pInformationContainer, SIGNAL(currentChanged(int)), SLOT(onInformationPageChanged()));
+	// query aptDB for updates every 2s
+	connect(&timer, SIGNAL(timeout()), SLOT(checkAptDbForUpdates()));
+	timer.start(2000);
 }
 
 PackageSearchImpl::~PackageSearchImpl()
@@ -150,85 +173,71 @@ PackageSearchImpl::~PackageSearchImpl()
 	delete _pApt;
 	delete _pDebtags;
 	delete _pTextsearch;
-
 }
 
 
-void PackageSearchImpl::init()
+/////////////////////////////////////////////////////
+// Initialisation
+/////////////////////////////////////////////////////
+
+void PackageSearchImpl::initDirectories()
 {
-	{ // search for the icon and doc pathes
-		if  ( QFile("../doc/content.html").exists() )
-		{
-			QDir docDir = QDir::current();
-			docDir.cd("../doc/");
-			_docDir = docDir.absolutePath()+"/";
-		}
-		else if ( QFile("doc/content.html").exists() )
-		{
-			QDir docDir = QDir::current();
-			docDir.cd("doc/");
-			_docDir = docDir.absolutePath()+"/";
-		}
-		else if ( QFile("/usr/share/doc/packagesearch/content.html").exists() )
-			_docDir = "/usr/share/doc/packagesearch/";
-		else
-			cerr << "Could not find doc directory. It must be located at "
-			"/usr/share/doc/packagesearch/, ../doc/ or doc/."<<endl;
-		if ( QFile("../icons/packagesearch.png").exists() )
-			_iconDir = "../icons/";
-		else if ( QFile("icons/packagesearch.png").exists() )
-			_iconDir = "icons/";
-		else if ( QFile("/usr/share/pixmaps/packagesearch/packagesearch.png").exists() )
-			_iconDir = "/usr/share/pixmaps/packagesearch/";
-		else
-			cerr << "Could not find icon directory. It must located at "
-				"/usr/share/pixmaps/packagesearch, ../icons/ or icons/."<<endl;
-	} // search the data paths
-	QPixmap appIcon(_iconDir+"packagesearch.png");
-	setWindowIcon(appIcon);
-
-	_pWhatsThisAction = QWhatsThis::createAction(this);
-
-	// don't change order, because initMenus relies on an initialized toolbar
-	initToolbars();
-	initMenus();
-		
-	
-	uint width = 700;
-	uint height = 600;
-	
-	QList<int> sizes;
-	sizes.push_back(width/2);
-	sizes.push_back((width+1)/2);
-	
-	resize(width, height);
-	_pUpperVSplitter->setSizes(sizes);
-	_pLowerVSplitter->setSizes(sizes);
-
-
-	updateBrowseToolbar();
+	// search for doc path
+	if  ( QFile("../doc/content.html").exists() )
+	{
+		QDir docDir = QDir::current();
+		docDir.cd("../doc/");
+		_docDir = docDir.absolutePath()+"/";
+	}
+	else if ( QFile("doc/content.html").exists() )
+	{
+		QDir docDir = QDir::current();
+		docDir.cd("doc/");
+		_docDir = docDir.absolutePath()+"/";
+	}
+	else if ( QFile("/usr/share/doc/packagesearch/content.html").exists() )
+		_docDir = "/usr/share/doc/packagesearch/";
+	else
+		cerr << "Could not find doc directory. It must be located at "
+		"/usr/share/doc/packagesearch/, ../doc/ or doc/."<<endl;
+	// search for icon path
+	if ( QFile("../icons/packagesearch.png").exists() )
+		_iconDir = "../icons/";
+	else if ( QFile("icons/packagesearch.png").exists() )
+		_iconDir = "icons/";
+	else if ( QFile("/usr/share/pixmaps/packagesearch/packagesearch.png").exists() )
+		_iconDir = "/usr/share/pixmaps/packagesearch/";
+	else
+		cerr << "Could not find icon directory. It must located at "
+			"/usr/share/pixmaps/packagesearch, ../icons/ or icons/."<<endl;
 }
 
 
 void PackageSearchImpl::initToolbars()
 {
-	_pWhatsThisAction->setShortcut(QKeySequence("Shift+F1"));
 	_pMainToolBar = addToolBar(tr("Main Toolbar"));
 	_pMainToolBar->setIconSize(QSize(16,16));
 	_pMainToolBar->addAction(_pWhatsThisAction);
 	_nameToToolBar["Main"] = _pMainToolBar;
+
+	// setting up brows toolbar
+	QIcon backIcon(_iconDir + "back.png");
+	QIcon forwardIcon(_iconDir + "forward.png");
+	_pBackButton->setIcon(backIcon);
+	_pForwardButton->setIcon(forwardIcon);
+	updateBrowseToolbar();
+
 }
 
 void PackageSearchImpl::initMenus()
 {
-	_pHelpMenu->insertAction(helpContentsAction, _pWhatsThisAction);
 	_pViewMenu->addAction(_pMainToolBar->toggleViewAction());
+	_pHelpMenu->insertAction(_pHelpContentsAction, _pWhatsThisAction);
 
 	_nameToMenu["Packagesearch"] = _pPackagesearchMenu;
 	_nameToMenu["View"] = _pViewMenu;
 	_nameToMenu["Packages"] = _pPackagesMenu;
 	_nameToMenu["System"] = _pSystemMenu;
-	_nameToMenu["Plugins"] = _pPluginsMenu;
 	_nameToMenu["Help"] = _pHelpMenu;
 }
 
@@ -248,26 +257,12 @@ void PackageSearchImpl::initialize()
 	
 	packageView()->initialize();
 
-	// remove all columns for plugins which are not loaded
-	{
-		QStringList columns;
-		for (ShortInformationPluginContainer::const_iterator it = _shortInformationPlugins.begin();
-			it != _shortInformationPlugins.end(); ++it)
-		{
-			columns.push_back((*it)->shortInformationCaption());
-		}
-// 		_pPackageListViewControl->removeColumnsNotInList(columns);
-	}
 	_pInformationContainer->setCurrentIndex(0);
 	const set<string>& packages_ = packages();
-	// First copy the package names into a stringlist, and then add the whole list
-	// to the combobox, because since QT4 _pPackageSelection->insertItem() is totally inefficient
-	QStringList packageNames;
 	for (set<string>::const_iterator it = packages_.begin(); it != packages_.end(); ++it)
 	{
-		packageNames.push_back(toQString(*it));
+		_pPackageSelection->addItem(toQString(*it));
 	}
-	_pPackageSelection->insertItems(0, packageNames);
 	_pPackageSelection->setMinimumWidth(100);
 	setPackageActionsEnabled(false);
 }
@@ -280,7 +275,9 @@ void PackageSearchImpl::saveSettings()
 {
 	NXml::XmlData xmlData("packagesearch");
 	QDomElement root = xmlData.root();
-	xmlData.addAttribute(root, QString("1"), "settingsVersion");
+	xmlData.addAttribute(root, QString("2"), "settingsVersion");
+	// changes:
+	// settings version 2: added "system" node
 	
 	xmlData.addAttribute(root, _pMainToolBar->toggleViewAction()->isChecked(), "showMainToolbar");
 	
@@ -299,7 +296,12 @@ void PackageSearchImpl::saveSettings()
 	xmlData.addAttribute(window, sizes[0], "lowerVSplitterSize1");
 	xmlData.addAttribute(window, sizes[1], "lowerVSplitterSize2");
 
+	xmlData.addAttribute(root, _pMainToolBar->toggleViewAction()->isChecked(), "showMainToolbar");
+
  	packageView()->saveSettings(xmlData, root);
+	
+	QDomElement system = xmlData.addElement(xmlData.root(), "system");
+	xmlData.addAttribute(system, NApplication::RunCommand::gainRootCommand(), "gainRootCommand");
 	_pPluginManager->saveSettings(xmlData, root);
 	if ( !xmlData.writeFile(_settingsFilename) )
 		reportError(tr("Unable to write settings"), tr("Unable to write settings to") +
@@ -378,6 +380,14 @@ void PackageSearchImpl::loadSettings()
 			element = NXml::getNextElement(element);	
 		}
 	}	
+	// if preferences contain a "system" node
+	if (element.tagName() == "system")
+	{
+		int gainRootCommand;
+		NXml::getAttribute(element, gainRootCommand, "gainRootCommand", 0);
+		NApplication::RunCommand::setGainRootCommand((NApplication::GainRoot) gainRootCommand);
+		element = NXml::getNextElement(element);
+	}
 	_pPluginManager->loadSettings(element);
 }
 
@@ -412,14 +422,18 @@ void PackageSearchImpl::reportWarning(const QString& title, const QString& messa
 
 void PackageSearchImpl::reportBusy(NPlugin::Plugin*, const QString& message)
 {
-	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+	// order is important here, since setOverrideCursor() triggers an update of the UI,
+	// and thus immediately updates the statusbar
 	statusBar()->showMessage(message);
+	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
 }
 
 void PackageSearchImpl::reportReady(NPlugin::Plugin* )
 {
+	// order is important here, since setOverrideCursor() triggers an update of the UI,
+	// and thus immediately updates the statusbar
+	statusBar()->clearMessage();
 	qApp->restoreOverrideCursor();
-	statusBar()->showMessage(tr("Ready"));
 }
 
 
@@ -433,18 +447,12 @@ const set<string>& PackageSearchImpl::packages() const
 	static bool initialized = false;
 	if (!initialized)
 	{	
-		// I used to use the real apt code here, but I gained only around 400ms this is not worth the
-		// effort...
-		QTime t;
-		t.start();
+		typedef ept::apt::Apt Apt;
 		initialized = true;
-		NApplication::RunCommandForOutput ro("");
-		ro.run("apt-cache pkgnames --no-all-names");
-		QStringList packages = ro.getOutput();
-		for(QStringList::iterator it = packages.begin(); it != packages.end(); ++it)
-			// const cast OK here, since this is lazy initialization, since const_cast works only
-			// for pointers and references, I had to get the address here
-			(const_cast< set<string>* >(&_packages))->insert(toString(*it));
+		for (Apt::Iterator it = _pApt->begin(); it != _pApt->end(); ++it)
+		{
+			_packages.insert(*it);
+		}
 	}
 	return _packages;
 }
@@ -540,6 +548,7 @@ void PackageSearchImpl::removePlugin(NPlugin::Plugin* pPlugin)
 
 /////////////////////////////////////////////////////
 // IPluginUser Helper Methods ///////////////////////
+/////////////////////////////////////////////////////
 
 void PackageSearchImpl::addShortInformationPlugin(NPlugin::ShortInformationPlugin* pPlugin)
 {
@@ -615,7 +624,6 @@ void PackageSearchImpl::updateSearchPluginGui()
 	QVBoxLayout* pLayout = new QVBoxLayout(_pShortSearchFrame);
 	pLayout->setMargin(5);
 	pLayout->setSpacing(10);
-	
 	NExtStd::for_each(_searchPlugins.begin(), _searchPlugins.end(), 
 		&PackageSearchImpl::addSearchPluginToGui, this);
 	if (_pInputWidgetsContainer->count()>0)
@@ -645,59 +653,32 @@ void PackageSearchImpl::addSearchPluginToGui(NPlugin::SearchPlugin* pPlugin)
 
 void PackageSearchImpl::updateInformationPluginGui()
 {
-	QString tmpCurrentPackage = _currentPackage;
-	_currentPackage =  "";
-	// clear the information plugin GUI 
 	_pInformationContainer->clear();
-	// add a dummy tab, so that the widgets are not always repainted
 	bool detailPageAdded = false;
-	for (InformationPluginContainer::iterator it = _informationPlugins.begin();
+	// add all information plugins in order of their priorities, inserting the details
+	// information page between
+	for (InformationPluginContainer::const_iterator it = _informationPlugins.begin();
 		it != _informationPlugins.end(); ++it)
 	{
+		NPlugin::InformationPlugin* pPlugin = *it;
 		if ( !detailPageAdded && 
-			((*it)->informationPriority() >= _DETAILS_INFORMATION_PRIORITY) )
+			(pPlugin->informationPriority() >= _DETAILS_INFORMATION_PRIORITY) )
 		{
 			_pInformationContainer->addTab(_pDetailsView, tr("Details"));
 			detailPageAdded = true;
 		}
-		addInformationPluginToGui(*it);
+		if (pPlugin->informationWidget() != 0)	// if the plugin offers an information widget
+		{
+			_pInformationContainer->addTab(
+				pPlugin->informationWidget(), 
+				pPlugin->informationWidgetTitle()
+			);
+		}
 	}
 	if (!detailPageAdded)
 		_pInformationContainer->addTab(_pDetailsView, tr("Details"));
 	_pInformationContainer->setCurrentIndex(0);
-	setSelectedPackage(tmpCurrentPackage);
-/*	{
-		QWidget* pParent = dynamic_cast<QWidget*>(_pInformationContainer->parent());
-		delete _pInformationContainer;
-		_pInformationContainer = new QTabWidget(pParent, "InformationContainer");
-		_pDetailsView = new QTextBrowser( _pInformationContainer, "_pDetailsView" );
-		bool detailPageAdded = false;
-		for (InformationPluginContainer::iterator it = _informationPlugins.begin();
-			it != _informationPlugins.end(); ++it)
-		{
-			if ( !detailPageAdded && 
-				((*it)->informationPriority() >= _DETAILS_INFORMATION_PRIORITY) )
-			{
-				_pInformationContainer->insertTab(_pDetailsView, tr("Details"));
-				detailPageAdded = true;
-			}
-			addInformationPluginToGui(*it);
-		}
-		_pInformationLayout->add(_pInformationContainer);
-	}*/
-}
-
-void PackageSearchImpl::addInformationPluginToGui(NPlugin::InformationPlugin* pPlugin)
-{
-	assert(pPlugin);
-	if (pPlugin->informationWidget() != 0)	// if there is a special information widget
-	{
-		// insert the widget
-		_pInformationContainer->addTab(
-			pPlugin->informationWidget(), 
-			pPlugin->informationWidgetTitle()
-		);
-	}
+	updatePackageInformation(_currentPackage);
 }
 
 NPlugin::ShortInformationPlugin* PackageSearchImpl::getShortInformationPluginWithCaption(
@@ -714,12 +695,8 @@ NPlugin::ShortInformationPlugin* PackageSearchImpl::getShortInformationPluginWit
 
 void PackageSearchImpl::onClearSearch()
 {
-	for (
-		SearchPluginContainer::iterator it = _searchPlugins.begin();
-		it != _searchPlugins.end();
-		++it
-	)
- 		(*it)->clearSearch();
+	for_each(_searchPlugins.begin(), _searchPlugins.end(),
+			mem_fun(&NPlugin::SearchPlugin::clearSearch));
 }
 
 
@@ -796,14 +773,12 @@ void PackageSearchImpl::onSearchChanged(NPlugin::SearchPlugin*)
 	reportReady(0);
 }
 
-void PackageSearchImpl::showPackageInformation(const QString & package)
+void PackageSearchImpl::updatePackageInformation(const QString & package)
 {
-	// if the package to be shown is not the one selected in the package view, deselect it in the package view
-	if (packageView()->selectedPackage() != package)
-		packageView()->clearSelection();
+	qDebug() << "updatePackageInformation(" << package << ")";
 	_pDetailsView->clear();
 	
-	QString detailedText;	// detailed information text (in HTML)
+	QString detailedText;	// information text for "Details" tab (in HTML)
 	for ( InformationPluginContainer::iterator it = _informationPlugins.begin();
 		it != _informationPlugins.end(); ++it )
 	{
@@ -832,7 +807,7 @@ void PackageSearchImpl::showPackageInformation(const QString & package)
 			}
 			if (_pInformationContainer->currentWidget() == pPlugin->informationWidget())
 			{
-			// update the tab only if it is currenly active
+				// update the tab only if it is currenly active
 				try  {
 					pPlugin->updateInformationWidget(toString(package));
 				}
@@ -847,11 +822,6 @@ void PackageSearchImpl::showPackageInformation(const QString & package)
 		}
 	}
 	_pDetailsView->setHtml("<p>" + detailedText + "<p>");
-// 	// Begin Debug
-// 	static QTextEdit* p = new QTextEdit();
-// 	p->show();
-// 	p->setPlainText(_pDetailsView->toHtml());
-// 	// End Debug
 }
 
 void PackageSearchImpl::onInformationPageChanged()
@@ -889,13 +859,33 @@ void PackageSearchImpl::onControlPlugins()
 
 void PackageSearchImpl::onPreferences()
 {
-	NPlugin::PluginSettingsDlg dlg(this);
+	NPackageSearch::SettingsDlg dlg(this);
+	// TODO grey out SUDO button if sudo is not available
+	switch (NApplication::RunCommand::gainRootCommand())
+	{
+		case NApplication::SU:
+			dlg._pSuButton->setChecked(true);
+			break;
+		case NApplication::SUDO:
+			dlg._pSudoButton->setChecked(true);
+			break;
+	}
+	// if sudo is not executable
+	if (! (QFile::permissions(NApplication::GainRootPaths::sudo) & QFile::ExeUser) )
+		dlg._pSudoButton->setEnabled(false);
 	vector<NPlugin::PluginContainer*> plugins = _pPluginManager->getLoadedPlugins();
 	for_each(plugins.begin(), plugins.end(), 
-			bind1st( mem_fun(&NPlugin::PluginSettingsDlg::addPlugin), &dlg) );
+			bind1st( mem_fun(&NPackageSearch::SettingsDlg::addPlugin), &dlg) );
 	if ( dlg.exec() == QDialog::Accepted )
+	{
+		if (dlg._pSuButton->isChecked())
+			NApplication::RunCommand::setGainRootCommand(NApplication::SU);
+		else if (dlg._pSudoButton->isChecked())
+			NApplication::RunCommand::setGainRootCommand(NApplication::SUDO);
+			
 		for_each( plugins.begin(), plugins.end(),
 				mem_fun(&NPlugin::PluginContainer::applySettings) );
+	}
 }
 
 
@@ -906,20 +896,6 @@ void PackageSearchImpl::closeEvent(QCloseEvent* pE)
 }
 
 
-void PackageSearchImpl::onPackageSelectionChanged(QString package)
-{
-	if ( !package.isNull() )
-	{
-		selectNewPackage(package);
-		setPackageActionsEnabled(true);
-	}
-	else
-	{
-		_pDetailsView->clear();
-		setPackageActionsEnabled(false);
-	}
-}
-
 void PackageSearchImpl::onLinkClicked( const QUrl& link)
 {
 	selectNewPackage(link.toString());
@@ -927,25 +903,43 @@ void PackageSearchImpl::onLinkClicked( const QUrl& link)
 
 void PackageSearchImpl::onForward()
 {
-	setSelectedPackage(_viewHistory.forward());
+	setCurrentPackage(_viewHistory.forward());
 	updateBrowseToolbar();
 }
 
 void PackageSearchImpl::onBack()
 {
-	setSelectedPackage(_viewHistory.back());
+	setCurrentPackage(_viewHistory.back());
 	updateBrowseToolbar();
 }
 
 void PackageSearchImpl::selectNewPackage(const QString& package)
 {
-	// reselect the package even if already selected to reflect changes due to a changed search
-	setSelectedPackage(package);
-	if ( _viewHistory.empty() || _viewHistory.current() != package)
+	qDebug() << "selectNewPackage(" << package << ") called";
+	if (package.isEmpty()) 
 	{
-		_viewHistory.append(package);
-		updateBrowseToolbar();
+		setPackageActionsEnabled(false);
+		_pDetailsView->clear();
 	}
+	else
+	{
+		// reselect the package even if already selected to reflect changes due to a changed search
+		setCurrentPackage(package);
+		if ( _viewHistory.empty() || _viewHistory.current() != package)
+		{
+			_viewHistory.append(package);
+			updateBrowseToolbar();
+		}
+	}
+}
+
+void PackageSearchImpl::onPackageSelectionChanged(QString package)
+{
+	if (!package.isEmpty()) 
+	{
+		selectNewPackage(package);
+}
+
 }
 
 void PackageSearchImpl::updateBrowseToolbar()
@@ -956,9 +950,9 @@ void PackageSearchImpl::updateBrowseToolbar()
 
 void PackageSearchImpl::onHelpContentsAction()
 {
-	QDialog* pDlg = new QDialog(this);
-	QVBoxLayout* pMainLayout = new QVBoxLayout(pDlg);
-	QTextBrowser *pHelpWindow = new QTextBrowser(pDlg); 
+	static QDialog* pDlg = new QDialog(this);
+	static QVBoxLayout* pMainLayout = new QVBoxLayout(pDlg);
+	static QTextBrowser *pHelpWindow = new QTextBrowser(pDlg); 
 	pHelpWindow->setWindowTitle(tr("Package Search Help Page"));
 	pHelpWindow->setSource(_docDir+"content.html");
 	pMainLayout->addWidget(pHelpWindow);
@@ -983,19 +977,31 @@ void PackageSearchImpl::setPackagesFound(int number)
 	_pPackagesFoundDisplay->setText(output);
 }
 
-void PackageSearchImpl::setSelectedPackage( const QString & package )
+void PackageSearchImpl::setCurrentPackage( const QString & package )
 {
+	setPackageActionsEnabled(true);
+	// if the package to be shown is not the one selected in the package view, deselect the 
+	// one in  the package view
+	if (packageView()->selectedPackage() != package)
+		packageView()->clearSelection();
 	if (package != _currentPackage)
 	{
 		_currentPackage = package;
+		// select the package in the package selection combo box
 		// this triggers a selectNewPackage() call  but it returns immidiately because 
 		// package == _currentPackage
 		int i = _pPackageSelection->findText(package);
+		// if we have a package which is in the package list, select it from there
 		if (i != -1)
 			_pPackageSelection->setCurrentIndex(i);
+		// if the package is not in the package list, change the text to reflect
+		// the current package
+		else
+			_pPackageSelection->setEditText(package);
 	}
-	// reselect the package even if already selected to reflect changes due to a changed search
-	showPackageInformation(package);
+	// update the package information even if the current package did not change
+	// to reflect changes due to a changed search
+	updatePackageInformation(package);
 }
 
 
@@ -1011,5 +1017,11 @@ void PackageSearchImpl::checkAptDbForUpdates()
 }
 
 
+void PackageSearchImpl::setTranslationDir(const QDir& dir) 
+{
+	_pPluginManager->setTranslationDir(dir);
+}
+
+
 
 
