@@ -29,6 +29,7 @@
 #include "history.h"
 
 class QCloseEvent;
+class QDir;
 class QToolBar;
 
 class TagSelection;
@@ -114,11 +115,8 @@ public:
 	virtual const set<string>& packages() const;
 	virtual NUtil::IProgressObserver* progressObserver() const;
 	virtual void reloadAptFrontCache();
-// 	ept::apt::Apt& apt() { return *_pApt; }
 	const ept::apt::Apt& apt() const { return *_pApt; }
-// 	ept::debtags::Debtags& debtags() { return *_pDebtags; }
 	const ept::debtags::Debtags& debtags() const { return *_pDebtags; }
-// 	ept::textsearch::TextSearch& textsearch() { return *_pTextsearch; }
 	const ept::textsearch::TextSearch& textsearch() const { return *_pTextsearch; }
 	//@}
 	/** @name IPluginUser interface
@@ -139,6 +137,9 @@ public:
 	  * @param pPlugin the plugin to be added
 	  */
 	virtual void addPlugin(NPlugin::PluginContainer* pPlugin);
+	
+	/** @brief Sets the directory were translations are stored. */
+	virtual void setTranslationDir(const QDir& dir);
 public slots:
 	/** Call this function after the dialog is shown to initialize the whole system. */
 	void initialize();
@@ -155,9 +156,9 @@ protected slots:
 	  * This request all plugins to update their information widgets and gets their
 	  * information text.\n
 	  * If package is empty, the views will be cleared. 
-	  * @note Do not call this function directly, but call setSelectedPackage() instead.
+	  * @note Do not call this function directly, but call setCurrentPackage() instead.
 	  */
-	virtual void showPackageInformation(const QString & package);
+	virtual void updatePackageInformation(const QString & package);
 	/** @brief Evaluates the plugin search results and displays them in the GUI.
 	  *
 	  * This is called whenever the search of a SearchPlugin changes.
@@ -173,42 +174,51 @@ protected slots:
 	/** This shows a settings dialog. */
 	virtual void onPreferences();
 	virtual void saveSettings();
+	/** @brief Loads the settings for packagesearch and the plugins.
+	  *
+	  * Must be called after setting _pPluginManager but before calling loadPlugins().
+	  * The settings will be stored in a data structure, and applied when the plugins
+	  * are loaded.
+	  */
 	virtual void loadSettings();
 	
-	/** @brief Updates the Details section in the Dialog (#_pDetailsView).
-	*
-	* Connected to the selectionChanged() signal from the package view (#_pPackageView).*/
-	void onPackageSelectionChanged(QString package);
-
-////////////////////////////////////////////////////
-// ui.h functions
-////////////////////////////////////////////////////
-
-void init();
-
-void onLinkClicked( const QUrl & link);
-void onForward();
-void onBack();
-/** @brief This chooses the given package to be shown and adds it to the history if
-  * different from the current entry.
-  */
-void selectNewPackage( const QString & package);
-/** Enables/ Disables the browse buttons */
-void updateBrowseToolbar();
-void onHelpContentsAction();
-void onHelpAboutAction();
-/** @brief Sets the number of packages that were found.
-  *
-  * This information is displayed in the dialog. 
-  * @param number number of packages found, hand -1 if no search is active */
-void setPackagesFound( int number );
-/** @brief This sets the package selected for display to package.
-	*
-	* It updates the combobox which shows the package which triggers the showPackageInformation()
-	* function. It does not add an entry to the history.
-	*/
-void setSelectedPackage( const QString & package );
+	void onLinkClicked(const QUrl& link);
+	void onForward();
+	void onBack();
 	
+	/** @brief Called, whenever the selected package in the package list changes.
+	  *
+	  * It calls selectNewPackage if package is not empty, otherwise it does nothing
+	  * (and thus _currentPackage remains unchanged).
+	  */
+	void onPackageSelectionChanged(QString package);
+	
+	/** @brief This chooses the given package to be shown and adds it to the history if
+	* different from the current entry.
+	*
+	* If it is called with an empty or a null string, it deselect the currently selected
+	* package and set the current package to be empty.
+		* @see setCurrentPackage()
+	*/
+	void selectNewPackage(const QString & package);
+	/** @brief This sets the package selected for display to package.
+		*
+		* It updates the combobox which shows the package which triggers the showPackageInformation()
+		* function. It does not add an entry to the history.
+		*
+		* @param package the new current package, should be a valid package
+		* @see selectNewPackage()
+		*/
+	void setCurrentPackage( const QString & package );
+	/** @brief Enables/ Disables the browse buttons */
+	void updateBrowseToolbar();
+	void onHelpContentsAction();
+	void onHelpAboutAction();
+	/** @brief Sets the number of packages that were found.
+	*
+	* This information is displayed in the dialog. 
+	* @param number number of packages found, hand -1 if no search is active */
+	void setPackagesFound( int number );
 	
 protected:
 	/** @brief Returns the package view (which is a QTableWidget) casted to PackageDisplayWidget. */
@@ -226,13 +236,6 @@ protected:
 	/** Actions to perform on close. */
 	virtual void closeEvent(QCloseEvent* pE);
 
-	/** @brief Sets up the missing toobar icons. */
-	void initToolbars();
-	/** @brief Sets up the missing menu entries. 
-	  *
-	  * @pre initToolbars() must have been called, because it relies on it to be initialized.
-	  */
-	void initMenus();
 
 	/** @brief Funtion object to filter search results with plugins which uses the filter 
 	  * technique.  */
@@ -263,10 +266,6 @@ protected:
 	  * Shows the information widget for all available information plugins in the correct 
 	  * order, removing outdated widgets. */
 	void updateInformationPluginGui();
-	/** @brief Adds the elements of the information plugin to the GUI. 
-	  *
-	  * @pre pPlugin != 0  */
-	void addInformationPluginToGui(NPlugin::InformationPlugin* pPlugin);
 	/** @brief Sets all the actions operating on packages to be enabled/disabled. 
 	  *
 	  * @see #_packageActions
@@ -277,6 +276,16 @@ protected:
 	  * @returns the plugin found or 0 if no plugin was found*/
 	NPlugin::ShortInformationPlugin* getShortInformationPluginWithCaption(const QString caption) const;
 private:
+	/** @brief Sets up the missing toobar icons. */
+	void initToolbars();
+	/** @brief Sets up the missing menu entries. 
+	  *
+	  * @pre initToolbars() must have been called, because it relies on it to be initialized.
+	  */
+	void initMenus();
+	/** @brief Determines the directories for icons, help files, etc. */
+	void initDirectories();
+	
 	ept::apt::Apt* _pApt;
 	ept::debtags::Debtags* _pDebtags;
 	ept::textsearch::TextSearch* _pTextsearch;
@@ -329,7 +338,7 @@ private:
 	  * It bases on the apt-cache so it assumes those packages as all. It is
 	  * lazy initialized.
 	  */
-	set<string> _packages;
+	mutable set<string> _packages;
 	/** @brief This plugin is used to display the package names in the short description. */
 	NPlugin::Plugin* _pPackageNamePlugin;
 	/** @brief This plugin is used to display and calculate the scores for the packages. */
