@@ -66,11 +66,25 @@ public:
 	  */
 	//@{
 	virtual bool search(std::set<string>& result, const QStringList& includePatterns, 
-		const QStringList& excludePatterns, bool searchDescr=true, bool caseSensitive=false) const;
+		const QStringList& excludePatterns, bool searchDescr, bool caseSensitive, bool wholeWords) const;
 	virtual bool search(std::set<string>& result, const QString& pattern, 
-		bool searchDescr=true, bool caseSensitive=false) const;
+		bool searchDescr, bool caseSensitive, bool wholeWords) const;
 	//@}
-
+	/** @brief Searches searchPattern within sourceString. 
+	  *
+	  * If searching for whole words only, any non alphabetic character is considered 
+	  * to be a word boundary.
+	  *	  
+	  * @param text the string to search in
+	  * @param searchPattern the string to search for
+	  * @param caseSensitive if true, the search is case sensitive.
+	  * @param wholeWords if true, searching only for whole words within 
+	  * sourceString to match the search pattern. 
+	  * 
+	  * @returns true if the search was successful, else false
+	  */
+	/// @todo add test case
+	static bool searchString(const QString& text, const QString& searchPattern, bool caseSensitive, bool wholeWords);
 };
 
 }
