@@ -8,6 +8,8 @@
 #include <qtimer.h>
 #include <qwidget.h>
 #include <QStringList>
+#include <QTime>
+#include <QDebug>
 
 #include <helpers.h>
 
@@ -91,6 +93,11 @@ void AptSearchPlugin::init(IProvider* pProvider)
 		SIGNAL(toggled(bool)), 
 		SLOT(evaluateSearch())
 	);
+	connect(
+		_pShortInputWidget->_pWholeWordsCheck,
+		SIGNAL(toggled(bool)), 
+		SLOT(evaluateSearch())
+	);
 }
 
 /////////////////////////////////////////////////////
@@ -138,7 +145,7 @@ map<string, float> AptSearchPlugin::getScore(const set<string>& packages) const
 
 void AptSearchPlugin::onInputTextChanged(const QString&)
 {
-	_pStatusBar->showMessage( tr("delayed evaluation - waiting for further input") );
+	_pStatusBar->showMessage(tr("Delayed evaluation - waiting for further input"), _delayTime );
 	_pDelayTimer->setSingleShot(true);
 	_pDelayTimer->start(_delayTime);
 }
@@ -148,7 +155,7 @@ void AptSearchPlugin::evaluateSearch()
 	// stop the delay timer in case that this evaluateSearch() was triggered by
 	// another event
 	_pDelayTimer->stop();
-	_pProvider->reportBusy(this, tr("Performing full text search on Package Database"));
+ 	_pProvider->reportBusy(this, tr("Performing full text search on package database"));
 	_searchResult.clear();
 	parseSearchExpression(_pShortInputWidget->_pAptSearchTextInput->text());
 	if ( !isInactive() )	// if the search is not empty
@@ -160,7 +167,8 @@ void AptSearchPlugin::evaluateSearch()
 				_includePatterns, 
 				_excludePatterns,  
 				_pShortInputWidget->_pSearchDescriptionsCheck->isChecked(),
-				_pShortInputWidget->_pCaseSensitiveCheck->isChecked()
+				_pShortInputWidget->_pCaseSensitiveCheck->isChecked(),
+				_pShortInputWidget->_pWholeWordsCheck->isChecked()
 			);
 		} catch (...) {
 			qWarning("Search threw an exception -> reloading apt-database");
@@ -171,7 +179,8 @@ void AptSearchPlugin::evaluateSearch()
 					_includePatterns, 
 					_excludePatterns,  
 					_pShortInputWidget->_pSearchDescriptionsCheck->isChecked(),
-					_pShortInputWidget->_pCaseSensitiveCheck->isChecked()
+					_pShortInputWidget->_pCaseSensitiveCheck->isChecked(),
+					_pShortInputWidget->_pWholeWordsCheck->isChecked()
 				);
 			} catch (...) {
 				qCritical("apt-search threw an exception -> expect corrupted results");
