@@ -48,8 +48,8 @@ public:
 	  * For a package it is neccessary to match all expressions from the given pattern list.
 	  * @param result the set where the search result should be inserted. The names of the matching packages 
 	  * will be added to result.
-	  * @param includePatterns list of patterns that must occur in the packages. The search is case insensitive.
-	  * @param excludePatterns list of patterns that must not occur in the packages. The search is case insensitive.
+	  * @param includePatterns list of patterns that must occur in the packages.
+	  * @param excludePatterns list of patterns that must not occur in the packages.
 	  * @param searchDescr defines if the description should be searched too, else only the
 	  * names will be serached
 	  * @param caseSensitive if the search should be performed case sensitive
@@ -57,18 +57,18 @@ public:
 	  * @pre !patterns.empty()
 	  */
 	virtual bool search(std::set<string>& result, const QStringList& includePatterns, 
-		const QStringList& excludePatterns, bool searchDescr=true, bool caseSensitive=false) const = 0;
+		const QStringList& excludePatterns, bool searchDescr, bool caseSensitive, bool wholeWords) const = 0;
 	/** @brief Searches for the given pattern in the package database.
 	  * @param result the set where the search result should be inserted. The names of the matching packages 
 	  * will be added to result.
-	  * @param pattern the patterns to be searched. The compare happens case insensitive.
+	  * @param pattern the patters to be searched.
 	  * @param searchDescr defines if the description should be searched too, else only the
 	  * names will be serached
 	  * @param caseSensitive if the search should be performed case sensitive
 	  * @returns if at least one package was found.
 	  */
 	virtual bool search(std::set<string>& result, const QString& pattern, 
-		bool searchDescr=true, bool caseSensitive=false) const = 0;
+		bool searchDescr, bool caseSensitive, bool wholeWords) const = 0;
 };
 
 };
