@@ -205,7 +205,7 @@ std::string DebtagsPlugin::createSearchExpression()
 
 void DebtagsPlugin::evaluateSearch()
 {
-	_pProvider->reportBusy(this, tr("Performing full text search on Package Database"));
+	_pProvider->reportBusy(this, tr("Performing tag search on package database"));
 //	statusBar()->message(tr("Searching Package Database for tags"));
 	_searchResult.clear();
 	string expression = createSearchExpression();
