@@ -34,8 +34,11 @@
 
 
 // Debug: Modeltest
-#include <modeltest.h>
+#ifdef __DEBUG
+#	include <modeltest.h>
+#endif
 
+#include <globals.h>
 
 #include "debtagssettingswidget.h"
 
@@ -48,7 +51,7 @@ extern "C"
 
 	NPlugin::PluginInformation get_pluginInformation()
 	{
-		return NPlugin::PluginInformation("debtagsplugin", "2.4", "Benjamin Mesing");
+		return NPlugin::PluginInformation("debtagsplugin", toString(NPackageSearch::VERSION), "Benjamin Mesing");
 	} 
 }
 
@@ -87,9 +90,8 @@ DebtagsPluginContainer::DebtagsPluginContainer()
  
 DebtagsPluginContainer::~DebtagsPluginContainer()
 {
+	unloadAllPlugins();
 	delete _pCommand;
-//	qDebug("Closing global aptFront Cache");
-//	cache::Global::get().close();
 }
 
 /////////////////////////////////////////////////////
@@ -103,8 +105,9 @@ bool DebtagsPluginContainer::init(IProvider* pProvider)
 	updateDebtags();
 	_pVocabularyModel = new NTagModel::VocabularyModel(this);
 
+#ifdef __DEBUG
 	new ModelTest(_pVocabularyModel, this);
-	
+#endif
 	
 	if (debtagsEnabled())
 	{
@@ -220,7 +223,7 @@ void DebtagsPluginContainer::updateDebtags()
 				"You must execute <tt><b>debtags update</b></tt> as root on the commandline to download "
 				"the database. If debtags is not on your system you can install it via "
 				"<tt><b>apt-get install debtags</b></tt><br>"
-				"Afterwards you can enable the debtags plugin via the plugin menu -> Control Plugins."
+				"Afterwards you can enable the debtags plugin via the Packagesearch menu -> Control Plugins."
 				"</p>")
 /*				"<p>"
 				"The original error message reported by debtags was:<br>"
