@@ -9,7 +9,6 @@
 #include <qpushbutton.h>
 
 #include <tagcoll/utils/set.h>
-//#include <ept/cache/debtags/tagmap.h>
 #include <ept/debtags/debtags.h>
 
 // NUtil
@@ -47,10 +46,7 @@ RelatedPlugin::~RelatedPlugin()
 	delete _pRelatedInput;
 	delete _pRelatedFeedbackWidget;
 }
- 
-/**
- * Methods
- */
+
 
 /////////////////////////////////////////////////////
 // Plugin Interface
@@ -58,17 +54,17 @@ RelatedPlugin::~RelatedPlugin()
 
 QString RelatedPlugin::title() const
 { 
-	return tr("Related Plugin"); 
+	return tr("Similar Plugin"); 
 }
 
 QString RelatedPlugin::briefDescription() const
 {
-	return tr("This searched for plugins related to a given package.");
+	return tr("Plugin for searching packages similar to another package.");
 }
 
 QString RelatedPlugin::description() const
 {
-	return tr("This searched for plugins related to a given package.");
+	return tr("Plugin for searching packages similar to another package.");
 }
 
 void RelatedPlugin::init(IProvider* pProvider)
@@ -104,12 +100,12 @@ void RelatedPlugin::init(IProvider* pProvider)
 }
 
 /////////////////////////////////////////////////////
-// Search Plugin Interface
+// SearchPlugin Interface
 /////////////////////////////////////////////////////
 
 QString RelatedPlugin::inputWidgetTitle() const	
 {
-	return tr("Related"); 
+	return tr("Similar"); 
 }
 
 QWidget* RelatedPlugin::inputWidget() const
@@ -173,9 +169,9 @@ void RelatedPlugin::onInputTextChanged(const QString& text)
 
 void RelatedPlugin::evaluateSearch()
 {
-	_pProvider->reportBusy(this, tr("Searching Package Database for related packages"));
+	_pProvider->reportBusy(this, tr("Searching for similar packages"));
 	_searchResult.clear();
-	_pRelatedFeedbackWidget->_pRelatedSearchTextView->setText(
+	_pRelatedFeedbackWidget->_pSimilarSearchTextView->setText(
 		_pRelatedInput->_pPackageInput->currentText()
 	);
  	string package = toString(_pRelatedInput->_pPackageInput->currentText());
