@@ -16,9 +16,9 @@
 #include <string>
 
 #include <QAbstractItemModel>
-#include <QHeaderView>
-#include <QContextMenuEvent>
 #include <QAction>
+#include <QContextMenuEvent>
+#include <QHeaderView>
 #include <QMenu>
 
 // NTagModel
@@ -30,7 +30,6 @@ using namespace std;
 namespace NTagModel
 {
 
-
 SelectedTagsView::SelectedTagsView(QWidget * parent)
  : QListView(parent), _selectedProxyModel(true, this)
 {
@@ -70,12 +69,12 @@ void SelectedTagsView::contextMenuEvent(QContextMenuEvent* pEvent)
 {
 	QMenu menu(this);
 	QModelIndex index = indexAt(pEvent->pos());
-	QAction* pClear = menu.addAction("Clear");
+	QAction* pClear = menu.addAction(tr("Clear"));
 	QAction* pRemove = 0;
 	// if the context menu was requested for a tag
 	if ( index.isValid() )
 	{
-		pRemove = menu.addAction("Remove");
+		pRemove = menu.addAction(tr("Remove"));
 	// not yet
 	// 	QAction* pSelectAsUnwanted = menu.addAction("Select as unwanted");
 	}
