@@ -22,7 +22,9 @@
 #include "vocabularymodelrole.h"
 #include "emptytagfilter.h"
 
-#include <modeltest.h>
+#ifdef __DEBUG
+#	include <modeltest.h>
+#endif
 #include <helpers.h>
 
 
@@ -90,9 +92,7 @@ UnselectedTagsView::UnselectedTagsView(const NPlugin::DebtagsPluginContainer* pC
 	
 	
 	_pTextFilter = new TextFilter(this);
-	// according to QT-Doc setting the column to -1 should search in all columns
-	// however this seems not to work
-	_pTextFilter->setFilterKeyColumn(1);
+	_pTextFilter->setFilterKeyColumn(-1);
 	_pTextFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 	_pTextFilter->setDynamicSortFilter(true);
 	
@@ -128,12 +128,14 @@ UnselectedTagsView::~UnselectedTagsView()
 void UnselectedTagsView::setModel(QAbstractItemModel* pModel)
 {
 	_filterChain.front()->setSourceModel(pModel);
+#ifdef __DEBUG
 // this is for debugging purposes, Modeltest are some really convenient classes to 
 // detect problems in ones model
-// 	for (	vector<QAbstractProxyModel*>::iterator it = _filterChain.begin(); it != _filterChain.end(); ++it )
-// 	{
-//  		new ModelTest(*it, this);
-// 	}
+	for (	vector<QAbstractProxyModel*>::iterator it = _filterChain.begin(); it != _filterChain.end(); ++it )
+	{
+  		new ModelTest(*it, this);
+	}
+#endif
  	QTreeView::setModel(_filterChain.back());
  	resizeColumnToContents(0);
 // 	resizeColumnToContents(0);
@@ -153,13 +155,13 @@ void UnselectedTagsView::contextMenuEvent(QContextMenuEvent* pEvent)
 	// if the context menu was requested for a tag
 	if ( index.isValid() && (model()->data(index, TypeRole).toInt() == TagTypeItem) )
 	{
-		pSelectAsWanted = menu.addAction("Add");
+		pSelectAsWanted = menu.addAction(tr("Add"));
 	// not yet
 	// 	QAction* pSelectAsUnwanted = menu.addAction("Select as unwanted");
 	}
 	menu.addSeparator();
-	QAction* pCollapseAll = menu.addAction("Collapse all");
-	QAction* pExpandAll = menu.addAction("Expand all");
+	QAction* pCollapseAll = menu.addAction(tr("Collapse all"));
+	QAction* pExpandAll = menu.addAction(tr("Expand all"));
 	QAction* pAction = menu.exec(pEvent->globalPos());
 	if (pAction)
 	{
