@@ -31,12 +31,28 @@ using namespace std;
 struct FacetData;
 struct TagData;
 
+/** @brief Base class for TagData and ItemData.
+  *
+  * Use by Vocabulary model to return the data.
+  */
 struct ItemData
 {
 	virtual ~ItemData() {};
+	/** @brief Returns if the item is a facet. */
 	virtual bool isFacet() const = 0;
+	/** @brief Returns the name of the item in user presentable form (i.e. "Text" instead of
+	  * "works-with-format:text"). 
+	  */
 	virtual QString name() const = 0;
+	/** @brief Returns the full user presentable text for the item (i.e. "Format: Text" instead of
+	  *  "works-with-format::text"). 
+	  */
+	virtual QString fullDisplayText() const = 0;
+	/** @brief Returns the full technical name (e.g. "works-with-format" for a facet and
+	  * "works-with-format::text" for a tag).
+	  */
 	virtual QString fullname() const = 0;
+	/** Returns the description of the item. */
 	virtual QString description() const = 0;
 	virtual const FacetData* toFacetData() const = 0;
 	virtual const TagData* toTagData() const = 0;
@@ -61,6 +77,7 @@ struct FacetData : public ItemData
 	virtual bool isFacet() const { return true; }
 	virtual QString name() const { return toQString(facet.shortDescription()); }
 	virtual QString fullname() const { return toQString(facet.name()); }
+	virtual QString fullDisplayText() const { return name(); };
 	virtual QString description() const { return toQString(facet.shortDescription()); }
 	virtual const FacetData* toFacetData() const { return this; };
 	virtual const TagData* toTagData() const { return 0; };
@@ -89,6 +106,11 @@ struct TagData : public ItemData
 	virtual bool isFacet() const { return false; }
 	virtual QString name() const { return toQString(tag.shortDescription()); }
 	virtual QString fullname() const { return toQString(tag.fullname()); }
+	virtual QString fullDisplayText() const 
+	{ QString tmp = toQString(tag.facet().shortDescription());
+		tmp += QString(": ");
+		tmp += name();
+		return tmp; };
 	virtual QString description() const { return toQString(tag.longDescription()); }
 	virtual const FacetData* toFacetData() const { return 0; };
 	virtual const TagData* toTagData() const { return this; };
