@@ -29,7 +29,7 @@ ScoreDisplayPlugin::ScoreDisplayPlugin()
  : ShortInformationPlugin(),
  	_title(tr("Score Display Plugin")),
 	_briefDescription(tr("Displays the package scores")),
-	_description(tr("Displays the search scores of the packages returned by the current score.<br>\n"
+	_description(tr("Displays the search scores of the packages returned by the current search.<br>\n"
 	"The higher the scores, the better the packages matches to the search."))
 {
 }
